@@ -3,32 +3,36 @@ import logging
 import os
 import ssl
 import types
+from copy import deepcopy
 from typing import Optional, Tuple
 
 from apispec import APISpec
-from brewtils.models import Event, Events
-from brewtils.models import Principal
+from brewtils.models import Event, Events, Principal
 from brewtils.schemas import (
     CommandSchema,
     CronTriggerSchema,
     DateTriggerSchema,
     EventSchema,
+    FileStatusSchema,
     GardenSchema,
     InstanceSchema,
     IntervalTriggerSchema,
+    JobExportInputSchema,
+    JobExportSchema,
     JobSchema,
+    LegacyRoleSchema,
     LoggingConfigSchema,
     OperationSchema,
     ParameterSchema,
     PatchSchema,
-    PrincipalSchema,
     QueueSchema,
     RefreshTokenSchema,
     RequestSchema,
-    RoleSchema,
     RunnerSchema,
     SystemSchema,
-    FileStatusSchema,
+    UserCreateSchema,
+    UserListSchema,
+    UserSchema,
 )
 from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop
@@ -44,9 +48,9 @@ import beer_garden.events
 import beer_garden.log
 import beer_garden.requests
 import beer_garden.router
-from beer_garden.api.http.authorization import anonymous_principal as load_anonymous
 from beer_garden.api.http.client import SerializeHelper
 from beer_garden.api.http.processors import EventManager, websocket_publish
+from beer_garden.api.http.schemas.v1.login import LoginInputSchema, LoginResponseSchema
 from beer_garden.events import publish
 
 io_loop: IOLoop = None
@@ -86,9 +90,6 @@ async def startup():
     """
     global anonymous_principal
 
-    # Need to wait until after mongo connection established to load
-    anonymous_principal = load_anonymous()
-
     http_config = config.get("entry.http")
     logger.debug(f"Starting HTTP server on {http_config.host}:{http_config.port}")
     server.listen(http_config.port, http_config.host)
@@ -141,8 +142,8 @@ def _setup_application():
     moto.create_connection(db_config=beer_garden.config.get("db"))
 
     auth_config = config.get("auth")
-    if not auth_config.token.secret:
-        auth_config.token.secret = os.urandom(20)
+    if not auth_config.token_secret:
+        auth_config.token_secret = os.urandom(20)
         if auth_config.enabled:
             logger.warning(
                 "Brew-view was started with authentication enabled and no "
@@ -178,10 +179,7 @@ def _setup_tornado_app() -> Application:
         (rf"{prefix}api/v1/requests/?", v1.request.RequestListAPI),
         (rf"{prefix}api/v1/systems/?", v1.system.SystemListAPI),
         (rf"{prefix}api/v1/queues/?", v1.queue.QueueListAPI),
-        (rf"{prefix}api/v1/users/?", v1.user.UsersAPI),
-        (rf"{prefix}api/v1/roles/?", v1.role.RolesAPI),
-        (rf"{prefix}api/v1/permissions/?", v1.permissions.PermissionsAPI),
-        (rf"{prefix}api/v1/tokens/?", v1.token.TokenListAPI),
+        (rf"{prefix}api/v1/users/?", v1.user.UserListAPI),
         (rf"{prefix}api/v1/admin/?", v1.admin.AdminAPI),
         (rf"{prefix}api/v1/jobs/?", v1.job.JobListAPI),
         (rf"{prefix}api/v1/gardens/?", v1.garden.GardenListAPI),
@@ -195,11 +193,13 @@ def _setup_tornado_app() -> Application:
         (rf"{prefix}api/v1/systems/(\w+)/?", v1.system.SystemAPI),
         (rf"{prefix}api/v1/queues/([\w\.-]+)/?", v1.queue.QueueAPI),
         (rf"{prefix}api/v1/users/(\w+)/?", v1.user.UserAPI),
-        (rf"{prefix}api/v1/roles/(\w+)/?", v1.role.RoleAPI),
-        (rf"{prefix}api/v1/tokens/(\w+)/?", v1.token.TokenAPI),
         (rf"{prefix}api/v1/jobs/(\w+)/?", v1.job.JobAPI),
         (rf"{prefix}api/v1/logging/?", v1.logging.LoggingAPI),
-        (rf"{prefix}api/v1/gardens/([\w%]+)/?", v1.garden.GardenAPI),
+        (rf"{prefix}api/v1/gardens/(.*)/?", v1.garden.GardenAPI),
+        (rf"{prefix}api/v1/export/jobs/?", v1.job.JobExportAPI),
+        (rf"{prefix}api/v1/import/jobs/?", v1.job.JobImportAPI),
+        (rf"{prefix}api/v1/login", v1.login.LoginAPI),
+        (rf"{prefix}api/v1/whoami", v1.user.WhoAmIAPI),
         # Beta
         (rf"{prefix}api/vbeta/events/?", vbeta.event.EventPublisherAPI),
         (rf"{prefix}api/vbeta/runners/?", vbeta.runner.RunnerListAPI),
@@ -215,10 +215,8 @@ def _setup_tornado_app() -> Application:
         (rf"{prefix}api/vbeta/file/?", vbeta.file.RawFileListAPI),
         (rf"{prefix}api/vbeta/file/(\w+)/?", vbeta.file.RawFileAPI),
         # V2
-        (rf"{prefix}api/v2/users/?", v1.user.UsersAPI),
+        (rf"{prefix}api/v2/users/?", v1.user.UserListAPI),
         (rf"{prefix}api/v2/users/(\w+)/?", v1.user.UserAPI),
-        (rf"{prefix}api/v2/tokens/?", v1.token.TokenListAPI),
-        (rf"{prefix}api/v2/tokens/(\w+)/?", v1.token.TokenAPI),
         # Deprecated
         (rf"{prefix}api/v1/commands/?", v1.command.CommandListAPI),
         (rf"{prefix}api/v1/commands/(\w+)/?", v1.command.CommandAPIOld),
@@ -248,7 +246,7 @@ def _setup_tornado_app() -> Application:
     return Application(
         published_url_specs + unpublished_url_specs,
         debug=ui_config.debug_mode,
-        cookie_secret=auth_config.token.secret,
+        cookie_secret=auth_config.token_secret,
         autoreload=False,
         client=SerializeHelper(),
     )
@@ -300,11 +298,15 @@ def _load_swagger(url_specs, title=None):
     api_spec.definition("System", schema=SystemSchema)
     api_spec.definition("LoggingConfig", schema=LoggingConfigSchema)
     api_spec.definition("Event", schema=EventSchema)
-    api_spec.definition("User", schema=PrincipalSchema)
-    api_spec.definition("Role", schema=RoleSchema)
+    api_spec.definition("User", schema=UserSchema)
+    api_spec.definition("UserCreate", schema=UserCreateSchema)
+    api_spec.definition("UserList", schema=UserListSchema)
+    api_spec.definition("Role", schema=LegacyRoleSchema)
     api_spec.definition("Queue", schema=QueueSchema)
     api_spec.definition("Operation", schema=OperationSchema)
     api_spec.definition("FileStatus", schema=FileStatusSchema)
+    api_spec.definition("LoginInput", schema=LoginInputSchema)
+    api_spec.definition("LoginResponse", schema=LoginResponseSchema)
 
     api_spec.definition("RefreshToken", schema=RefreshTokenSchema)
 
@@ -329,12 +331,22 @@ def _load_swagger(url_specs, title=None):
             {"$ref": "#/definitions/IntervalTrigger"},
         ]
     }
-    api_spec._definitions["Job"]["properties"]["trigger"] = trigger_properties
+    api_spec._definitions["Job"]["properties"]["trigger"] = trigger_properties  # noqa
+
+    api_spec.definition("JobExport", schema=JobExportInputSchema)
+    api_spec.definition("JobImport", schema=JobExportSchema)
+    api_spec._definitions["JobImport"]["properties"][  # noqa
+        "trigger"
+    ] = trigger_properties
 
     error = {"message": {"type": "string"}}
     api_spec.definition(
         "400Error", properties=error, description="Parameter validation error"
     )
+    api_spec.definition(
+        "401Error", properties=error, description="Authorization required"
+    )
+    api_spec.definition("403Error", properties=error, description="Access denied")
     api_spec.definition(
         "404Error", properties=error, description="Resource does not exist"
     )
@@ -367,6 +379,6 @@ def _event_callback(event):
         beer_garden.requests.handle_event,
     ]:
         try:
-            handler(event)
+            handler(deepcopy(event))
         except Exception as ex:
             logger.exception(f"Error executing callback for {event!r}: {ex}")
