@@ -3,16 +3,14 @@
 import beer_garden.api.http.handlers.v1.admin
 import beer_garden.api.http.handlers.v1.command
 import beer_garden.api.http.handlers.v1.event
+import beer_garden.api.http.handlers.v1.forward
+import beer_garden.api.http.handlers.v1.garden
 import beer_garden.api.http.handlers.v1.instance
 import beer_garden.api.http.handlers.v1.job
 import beer_garden.api.http.handlers.v1.logging
-import beer_garden.api.http.handlers.v1.permissions
+import beer_garden.api.http.handlers.v1.login
+import beer_garden.api.http.handlers.v1.namespace
 import beer_garden.api.http.handlers.v1.queue
 import beer_garden.api.http.handlers.v1.request
-import beer_garden.api.http.handlers.v1.role
 import beer_garden.api.http.handlers.v1.system
-import beer_garden.api.http.handlers.v1.token
 import beer_garden.api.http.handlers.v1.user
-import beer_garden.api.http.handlers.v1.garden
-import beer_garden.api.http.handlers.v1.forward
-import beer_garden.api.http.handlers.v1.namespace
