@@ -9,12 +9,10 @@ from brewtils.errors import (
 from brewtils.models import Operation
 from brewtils.schema_parser import SchemaParser
 
-from beer_garden.api.http.authorization import Permissions, authenticated
 from beer_garden.api.http.base_handler import BaseHandler, event_wait
 
 
 class InstanceAPI(BaseHandler):
-    @authenticated(permissions=[Permissions.READ])
     async def get(self, instance_id):
         """
         ---
@@ -45,7 +43,6 @@ class InstanceAPI(BaseHandler):
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
 
-    @authenticated(permissions=[Permissions.SYSTEM_ADMIN])
     async def delete(self, instance_id):
         """
         ---
@@ -73,7 +70,6 @@ class InstanceAPI(BaseHandler):
 
         self.set_status(204)
 
-    @authenticated(permissions=[Permissions.UPDATE])
     async def patch(self, instance_id):
         """
         ---
@@ -185,7 +181,6 @@ class InstanceAPI(BaseHandler):
 
 
 class InstanceLogAPI(BaseHandler):
-    @authenticated(permissions=[Permissions.UPDATE])
     async def get(self, instance_id):
         """
         ---
@@ -271,7 +266,6 @@ class InstanceLogAPI(BaseHandler):
 
 
 class InstanceQueuesAPI(BaseHandler):
-    @authenticated(permissions=[Permissions.READ])
     async def get(self, instance_id):
         """
         ---
