@@ -4,12 +4,10 @@ from brewtils.models import Operation
 from brewtils.schema_parser import SchemaParser
 from brewtils.schemas import SystemSchema
 
-from beer_garden.api.http.authorization import Permissions, authenticated
 from beer_garden.api.http.base_handler import BaseHandler
 
 
 class SystemAPI(BaseHandler):
-    @authenticated(permissions=[Permissions.READ])
     async def get(self, system_id):
         """
         ---
@@ -55,7 +53,6 @@ class SystemAPI(BaseHandler):
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
 
-    @authenticated(permissions=[Permissions.SYSTEM_ADMIN])
     async def delete(self, system_id):
         """
         Will give Bartender a chance to remove instances of this system from the
@@ -100,7 +97,6 @@ class SystemAPI(BaseHandler):
 
         self.set_status(204)
 
-    @authenticated(permissions=[Permissions.UPDATE])
     async def patch(self, system_id):
         """
         ---
@@ -213,7 +209,6 @@ class SystemAPI(BaseHandler):
 class SystemListAPI(BaseHandler):
     REQUEST_FIELDS = set(SystemSchema.get_attribute_names())
 
-    @authenticated(permissions=[Permissions.READ])
     async def get(self):
         """
         ---
@@ -323,7 +318,6 @@ class SystemListAPI(BaseHandler):
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
 
-    @authenticated(permissions=[Permissions.CREATE])
     async def post(self):
         """
         ---
