@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 import datetime
+import json
 import logging
 
 import pytz
 import six
-import sys
-import json
+from passlib.apps import custom_app_context
 
 try:
     from lark import ParseError
@@ -14,8 +14,22 @@ except ImportError:
     from lark.common import ParseError
 
     LarkError = ParseError
+from operator import attrgetter
+from typing import Optional, Tuple
+
+import brewtils.models
+from brewtils.choices import parse
+from brewtils.errors import ModelValidationError, RequestStatusTransitionError
+from brewtils.models import Command as BrewtilsCommand
+from brewtils.models import Instance as BrewtilsInstance
+from brewtils.models import Job as BrewtilsJob
+from brewtils.models import Parameter as BrewtilsParameter
+from brewtils.models import Request as BrewtilsRequest
 from bson.objectid import ObjectId
 from mongoengine import (
+    CASCADE,
+    NULLIFY,
+    PULL,
     BooleanField,
     DateTimeField,
     DictField,
@@ -24,31 +38,19 @@ from mongoengine import (
     EmbeddedDocument,
     EmbeddedDocumentField,
     EmbeddedDocumentListField,
+    FileField,
     GenericEmbeddedDocumentField,
-    LazyReferenceField,
     IntField,
+    LazyReferenceField,
     ListField,
     ObjectIdField,
     ReferenceField,
     StringField,
-    FileField,
-    CASCADE,
-    NULLIFY,
-    PULL,
 )
 from mongoengine.errors import DoesNotExist
 
-import brewtils.models
 from .fields import DummyField, StatusInfo
-from brewtils.choices import parse
-from brewtils.errors import ModelValidationError, RequestStatusTransitionError
-from brewtils.models import (
-    Command as BrewtilsCommand,
-    Instance as BrewtilsInstance,
-    Parameter as BrewtilsParameter,
-    Request as BrewtilsRequest,
-    Job as BrewtilsJob,
-)
+from .validators import validate_permissions
 
 __all__ = [
     "System",
@@ -59,7 +61,7 @@ __all__ = [
     "Choices",
     "Event",
     "Principal",
-    "Role",
+    "LegacyRole",
     "RefreshToken",
     "Job",
     "RequestTemplate",
@@ -70,8 +72,13 @@ __all__ = [
     "Garden",
     "File",
     "FileChunk",
+    "Role",
+    "RoleAssignment",
+    "User",
 ]
 
+REQUEST_MAX_PARAM_SIZE = 5 * 1_000_000
+
 
 class MongoModel:
     brewtils_model = None
@@ -125,19 +132,19 @@ class Choices(MongoModel, EmbeddedDocument):
         if self.type == "static" and not isinstance(self.value, (list, dict)):
             raise ModelValidationError(
                 f"Can not save choices '{self}': type is 'static' but the value is "
-                f"not a list or dictionary"
+                "not a list or dictionary"
             )
         elif self.type == "url" and not isinstance(self.value, six.string_types):
             raise ModelValidationError(
                 f"Can not save choices '{self}': type is 'url' but the value is "
-                f"not a string"
+                "not a string"
             )
         elif self.type == "command" and not isinstance(
             self.value, (six.string_types, dict)
         ):
             raise ModelValidationError(
                 f"Can not save choices '{self}': type is 'command' but the value is "
-                f"not a string or dict"
+                "not a string or dict"
             )
 
         if self.type == "command" and isinstance(self.value, dict):
@@ -195,14 +202,15 @@ class Parameter(MongoModel, EmbeddedDocument):
         if not self.nullable and self.optional and self.default is None:
             raise ModelValidationError(
                 f"Can not save Parameter {self}: For this Parameter nulls are not "
-                f"allowed, but the parameter is optional with no default defined."
+                "allowed, but the parameter is optional with no default defined."
             )
 
         if len(self.parameters) != len(
             set(parameter.key for parameter in self.parameters)
         ):
             raise ModelValidationError(
-                f"Can not save Parameter {self}: Contains Parameters with duplicate keys"
+                f"Can not save Parameter {self}: Contains Parameters with duplicate"
+                " keys"
             )
 
 
@@ -229,7 +237,8 @@ class Command(MongoModel, EmbeddedDocument):
 
         if self.command_type not in BrewtilsCommand.COMMAND_TYPES:
             raise ModelValidationError(
-                f"Can not save Command {self}: Invalid command type '{self.command_type}'"
+                f"Can not save Command {self}: Invalid command type"
+                f" '{self.command_type}'"
             )
 
         if self.output_type not in BrewtilsCommand.OUTPUT_TYPES:
@@ -396,39 +405,36 @@ class Request(MongoModel, Document):
     logger = logging.getLogger(__name__)
 
     def pre_serialize(self):
+        """Pull any fields out of GridFS"""
         encoding = "utf-8"
-        """If string output was over 16MB it was spilled over to the GridFS storage solution"""
+
         if self.output_gridfs:
-            self.logger.debug("~~~Retrieving output from gridfs")
+            self.logger.debug("Retrieving output from GridFS")
             self.output = self.output_gridfs.read().decode(encoding)
             self.output_gridfs = None
 
         if self.parameters_gridfs:
-            self.logger.debug("~~~Retrieving parameters from gridfs")
+            self.logger.debug("Retrieving parameters from GridFS")
             self.parameters = json.loads(self.parameters_gridfs.read().decode(encoding))
             self.parameters_gridfs = None
 
     def save(self, *args, **kwargs):
+        """Save a request, moving request attributes to GridFS if too big"""
         self.updated_at = datetime.datetime.utcnow()
-        max_size = 15 * 1_000_000
         encoding = "utf-8"
-        parameter_size = sys.getsizeof(self.parameters)
+
+        if self.parameters:
+            params_json = json.dumps(self.parameters)
+            if len(params_json) > REQUEST_MAX_PARAM_SIZE:
+                self.logger.debug("Parameters too bg, storing in GridFS")
+                self.parameters_gridfs.put(params_json, encoding=encoding)
+                self.parameters = None
 
         if self.output:
-            parameter_size = sys.getsizeof(self.parameters)
-            if parameter_size > max_size:
-                self.logger.info("~~~Parameter size too big, storing in gridfs")
-                self.parameters_gridfs.put(
-                    json.dumps(self.parameters), encoding=encoding
-                )
-                self.parameters = None
-                parameter_size = 0
-
-            # If the output size is too large, we switch it over
-            # Max size for Mongo is 16MB, switching over at 15MB to be safe
-            if self.output and (sys.getsizeof(self.output) + parameter_size) > max_size:
-                self.logger.info("~~~Output size too big, storing in gridfs")
-                self.output_gridfs.put(self.output, encoding=encoding)
+            output_json = json.dumps(self.output)
+            if len(output_json) > REQUEST_MAX_PARAM_SIZE:
+                self.logger.info("Output size too big, storing in gridfs")
+                self.output_gridfs.put(output_json, encoding=encoding)
                 self.output = None
 
         super(Request, self).save(*args, **kwargs)
@@ -446,7 +452,8 @@ class Request(MongoModel, Document):
             and self.command_type not in BrewtilsRequest.COMMAND_TYPES
         ):
             raise ModelValidationError(
-                f"Can not save Request {self}: Invalid command type '{self.command_type}'"
+                f"Can not save Request {self}: Invalid command type"
+                f" '{self.command_type}'"
             )
 
         if (
@@ -457,6 +464,15 @@ class Request(MongoModel, Document):
                 f"Can not save Request {self}: Invalid output type '{self.output_type}'"
             )
 
+        # Deal with has_parent
+        if self.has_parent is None:
+            self.has_parent = bool(self.parent)
+        elif self.has_parent != bool(self.parent):
+            raise ModelValidationError(
+                f"Cannot save Request {self}: parent value of {self.parent!r} is not "
+                f"consistent with has_parent value of {self.has_parent}"
+            )
+
     def clean_update(self):
         """Ensure that the update would not result in an illegal status transition"""
         # Get the original status
@@ -465,7 +481,7 @@ class Request(MongoModel, Document):
         if self.status != old_status:
             if old_status in BrewtilsRequest.COMPLETED_STATUSES:
                 raise RequestStatusTransitionError(
-                    f"Status for a request cannot be updated once it has been "
+                    "Status for a request cannot be updated once it has been "
                     f"completed. Current: {old_status}, Requested: {self.status}"
                 )
 
@@ -474,7 +490,7 @@ class Request(MongoModel, Document):
                 and self.status not in BrewtilsRequest.COMPLETED_STATUSES
             ):
                 raise RequestStatusTransitionError(
-                    f"Request status can only transition from IN_PROGRESS to a "
+                    "Request status can only transition from IN_PROGRESS to a "
                     f"completed status. Requested: {self.status}, completed statuses "
                     f"are {BrewtilsRequest.COMPLETED_STATUSES}."
                 )
@@ -538,8 +554,8 @@ class Event(MongoModel, Document):
     timestamp = DateTimeField()
 
 
-class Role(MongoModel, Document):
-    brewtils_model = brewtils.models.Role
+class LegacyRole(MongoModel, Document):
+    brewtils_model = brewtils.models.LegacyRole
 
     name = StringField(required=True)
     description = StringField()
@@ -557,7 +573,7 @@ class Principal(MongoModel, Document):
 
     username = StringField(required=True)
     hash = StringField()
-    roles = ListField(field=ReferenceField("Role", reverse_delete_rule=PULL))
+    roles = ListField(field=ReferenceField("LegacyRole", reverse_delete_rule=PULL))
     preferences = DictField()
     metadata = DictField()
 
@@ -662,7 +678,19 @@ class Job(MongoModel, Document):
         "auto_create_index": False,
         "index_background": True,
         "indexes": [
-            {"name": "next_run_time_index", "fields": ["next_run_time"], "sparse": True}
+            {
+                "name": "next_run_time_index",
+                "fields": ["next_run_time"],
+                "sparse": True,
+            },
+            {
+                "name": "job_system_fields",
+                "fields": [
+                    "request_template.namespace",
+                    "request_template.system",
+                    "request_template.system_version",
+                ],
+            },
         ],
     }
 
@@ -718,15 +746,79 @@ class Garden(MongoModel, Document):
     meta = {
         "auto_create_index": False,  # We need to manage this ourselves
         "index_background": True,
-        "indexes": [{"name": "unique_index", "fields": ["name"], "unique": True}],
+        "indexes": [
+            {"name": "unique_index", "fields": ["name"], "unique": True},
+            {
+                "name": "local_unique_index",
+                "fields": ["connection_type"],
+                "unique": True,
+                "partialFilterExpression": {"connection_type": "LOCAL"},
+            },
+        ],
     }
 
     def deep_save(self):
-        for system in self.systems:
-            system.save()
+        if self.connection_type != "LOCAL":
+            self._update_associated_systems()
 
         self.save()
 
+    def _update_associated_systems(self):
+        """If the call to the `deep_save` method is on a child garden object, we ensure
+        that when saving the systems, unknowns are deleted."""
+        # import moved here to avoid a circular import loop
+        from beer_garden.systems import get_systems, remove_system
+
+        logger = logging.getLogger(self.__class__.__name__)
+
+        def _get_system_triple(system: System) -> Tuple[str, str, str]:
+            return (
+                system.namespace,
+                system.name,
+                system.version,
+            )
+
+        our_namespaces = set(self.namespaces).union(
+            set(map(attrgetter("namespace"), self.systems))
+        )
+        # we leverage the fact that systems must be unique up to the triple of their
+        # namespaces, names and versions
+        child_systems_already_known = {
+            _get_system_triple(system): str(system.id)
+            for system in get_systems(
+                filter_params={"local": False, "namespace__in": our_namespaces}
+            )
+        }
+
+        for system in self.systems:
+            triple = _get_system_triple(system)
+
+            if triple in child_systems_already_known:
+                system_id_to_remove = child_systems_already_known.pop(triple)
+
+                if system_id_to_remove != str(system.id):
+                    # remove the system from before this update with the same triple
+                    logger.debug(
+                        f"Removing System <{triple[0]}"
+                        f", {triple[1]}"
+                        f", {triple[2]}> with ID={system_id_to_remove}"
+                        f"; doesn't match ID={str(system.id)}"
+                        " for known system with same attributes"
+                    )
+                    remove_system(system_id=system_id_to_remove)
+
+            system.save()
+
+        # if there's anything left over, delete those too; this could occur, e.g.,
+        # if a child system deleted a particular version of a plugin and installed
+        # another version of the same plugin
+        for bad_system_id in child_systems_already_known.values():
+            logger.debug(
+                f"Removing System with ID={str(bad_system_id)} because it "
+                f"matches no known system in child garden ({self.name})"
+            )
+            remove_system(system_id=bad_system_id)
+
 
 class SystemGardenMapping(MongoModel, Document):
     system = ReferenceField("System")
@@ -764,3 +856,102 @@ class FileChunk(MongoModel, Document):
 
 class RawFile(Document):
     file = FileField()
+
+
+class Role(Document):
+    name = StringField()
+    description = StringField()
+    permissions = ListField(field=StringField(), validation=validate_permissions)
+
+    meta = {
+        "indexes": [{"name": "unique_index", "fields": ["name"], "unique": True}],
+    }
+
+
+class RoleAssignmentDomain(EmbeddedDocument):
+    scope = StringField(required=True, choices=["Garden", "System", "Command"])
+    identifiers = DictField(required=True)
+
+
+class RoleAssignment(EmbeddedDocument):
+    domain = EmbeddedDocumentField(RoleAssignmentDomain)
+    role = ReferenceField("Role")
+
+
+class User(Document):
+    username = StringField(required=True)
+    password = StringField()
+    role_assignments = EmbeddedDocumentListField("RoleAssignment")
+
+    meta = {
+        "indexes": [{"name": "unique_index", "fields": ["username"], "unique": True}],
+    }
+
+    _permissions_cache: Optional[dict] = None
+
+    @property
+    def permissions(self) -> dict:
+        """Return the user's permissions organized by permission name. This is
+        calculated via beer_garden.authorization.permissions_for_user and is cached on
+        the User object to avoid unnecessary recalculation.
+
+        Returns:
+            dict: The user's permissions organized by permission name
+        """
+        from beer_garden.authorization import permissions_for_user
+
+        if self._permissions_cache is None:
+            self._permissions_cache = permissions_for_user(self)
+
+        return self._permissions_cache
+
+    def clear_permissions_cache(self) -> None:
+        """Clear the cached permission set for the user. This is useful if the user's
+        role assignments have been changed and you want to perform a permission check
+        using those new role assignments without reloading the entire user object.
+        """
+        self._permissions_cache = None
+
+    def set_permissions_cache(self, permissions: dict) -> None:
+        """Manually set the cached permission set for the user. This cache is typically
+        set and checked by the permissions property method. In cases where those
+        permissions are externally sourced (such as an access token in a web request
+        that was provided via initial authentication), this method can be used to
+        manually set the _permissions_cache value so that subsequent calls to
+        permissions related helper functions do not unnecessarily recalculate the user
+        permissions.
+
+        Args:
+            permissions: A dictionary containing the user's permissions. The format
+                should match the one produced by permissions_for_user in
+                beer_garden.authorization
+
+        Returns:
+            None
+        """
+        self._permissions_cache = permissions
+
+    def set_password(self, password: str):
+        """This helper should be used to set the user's password, rather than directly
+        assigning a value. This ensures that the password is stored as a hash rather
+        than in plain text
+
+        Args:
+            password: String to set as the user's password.
+
+        Returns:
+            None
+        """
+        self.password = custom_app_context.hash(password)
+
+    def verify_password(self, password: str):
+        """Checks the provided plaintext password against thea user's stored password
+        hash
+
+        Args:
+            password: Plaintext string to check against user's password"
+
+        Returns:
+            bool: True if the password matches, False otherwise
+        """
+        return custom_app_context.verify(password, self.password)
