@@ -1,84 +1,78 @@
 # -*- coding: utf-8 -*-
 import logging
 import os
+from typing import Union
+
+import yaml
 from bson import DBRef
+from marshmallow.exceptions import ValidationError as SchemaValidationError
 from mongoengine.connection import get_db
 from mongoengine.errors import (
     DoesNotExist,
     FieldDoesNotExist,
     InvalidDocumentError,
-    NotUniqueError,
+    ValidationError,
 )
 from passlib.apps import custom_app_context
 
+from beer_garden import config
+from beer_garden.errors import ConfigurationError
+from beer_garden.role import sync_roles
+
 logger = logging.getLogger(__name__)
 
 
+def ensure_local_garden():
+    """Creates an entry in the database for the local garden
+
+    The local garden info is configured via the configuration file. Internally
+    however, it is better to treat local and remote gardens the same in terms of how
+    we access them, etc. For that reason, we read the garden info from the configuration
+    and create or update the Garden database entry for it.
+    """
+    from .models import Garden
+
+    try:
+        garden = Garden.objects.get(connection_type="LOCAL")
+    except DoesNotExist:
+        garden = Garden(connection_type="LOCAL", status="RUNNING")
+
+    garden.name = config.get("garden.name")
+
+    garden.save()
+
+
 def ensure_roles():
     """Create roles if necessary
 
-    There are certain 'convenience' roles that will be created if this is a new
-    install (if no roles currently exist).
-
-    Then there are roles that MUST be present. These will always be created if
-    they do not exist.
+    If auth.role_definition_file is set in the main application config, this will
+    load that file and pass it over to sync_roles to make the Role definitions in the
+    database match what is defined in the file.
     """
-    from .models import Role
+    role_definition_file: Union[str, None] = config.get("auth.role_definition_file")
 
-    convenience_roles = [
-        Role(
-            name="bg-readonly",
-            description="Allows only standard read actions",
-            permissions=[
-                "bg-read",
-            ],
-        ),
-        Role(
-            name="bg-operator",
-            description="Standard Beergarden user role",
-            permissions=[
-                "bg-read",
-                "bg-create",
-                "bg-delete",
-            ],
-        ),
-    ]
+    if role_definition_file:
+        logger.info(f"Syncing role definitions from {role_definition_file}")
 
-    mandatory_roles = [
-        Role(
-            name="bg-anonymous",
-            description="Special role used for non-authenticated users",
-            permissions=[
-                "bg-read",
-            ],
-        ),
-        Role(name="bg-admin", description="Allows all actions", permissions=["bg-all"]),
-        Role(
-            name="bg-plugin",
-            description="Allows actions necessary for plugins to function",
-            permissions=[
-                "bg-update",
-                "bg-create",
-                "bg-delete",
-                "bg-read",
-            ],
-        ),
-    ]
-
-    # Only create convenience roles if this is a fresh database
-    if Role.objects.count() == 0:
-        logger.warning("No roles found: creating convenience roles")
-
-        for role in convenience_roles:
-            try:
-                # Since we have a race potential here catch the case where
-                # another process has already created the role
-                _create_role(role)
-            except NotUniqueError:
-                logger.warning("Role %s already exists" % role.name)
-
-    for role in mandatory_roles:
-        _create_role(role)
+        try:
+            with open(role_definition_file, "r") as filestream:
+                role_definitions = yaml.safe_load(filestream)
+                sync_roles(role_definitions)
+        except FileNotFoundError:
+            raise ConfigurationError(
+                f"Role definition file {role_definition_file} not found."
+            )
+        except SchemaValidationError:
+            raise ConfigurationError(
+                f"Error processing role definition file {role_definition_file}."
+            )
+        except ValidationError as validation_error:
+            raise ConfigurationError(
+                f"Invalid role definition in {role_definition_file}: "
+                f"{validation_error}"
+            )
+    else:
+        logger.info("auth.role_definition_file not defined. No roles will be synced.")
 
 
 def ensure_users(guest_login_enabled):
@@ -90,7 +84,7 @@ def ensure_users(guest_login_enabled):
     Then there are users that MUST be present. These will always be created if
     they do not exist.
     """
-    from .models import Principal, Role
+    from .models import Principal
 
     if _should_create_admin():
         default_password = os.environ.get("BG_DEFAULT_ADMIN_PASSWORD")
@@ -108,7 +102,7 @@ def ensure_users(guest_login_enabled):
         Principal(
             username="admin",
             hash=custom_app_context.hash(default_password),
-            roles=[Role.objects.get(name="bg-admin")],
+            roles=[],
             metadata={"auto_change": True, "changed": False},
         ).save()
 
@@ -132,7 +126,8 @@ def ensure_users(guest_login_enabled):
         if guest_login_enabled:
             logger.info("Creating anonymous user.")
             Principal(
-                username="anonymous", roles=[Role.objects.get(name="bg-anonymous")]
+                username="anonymous",
+                roles=[],
             ).save()
 
 
@@ -211,19 +206,19 @@ def ensure_v2_to_v3_model_migration():
     it would be better if we could seamlessly move the existing commands into existing
     Systems.
     """
-    from beer_garden.db.mongo.models import Role, System
+    from beer_garden.db.mongo.models import LegacyRole, System
 
     try:
-        if Role.objects.count() > 0:
-            _ = Role.objects()[0]
+        if LegacyRole.objects.count() > 0:
+            _ = LegacyRole.objects()[0]
         if System.objects.count() > 0:
             _ = System.objects()[0]
     except (FieldDoesNotExist, InvalidDocumentError):
         logger.warning(
-            "Encountered an error loading Roles or Systems. This is most likely because "
-            "the database is using the old (v2) style of storing in the database. "
-            "To fix this the roles, principles, systems, instances, and commands "
-            "collections will be dropped."
+            "Encountered an error loading Roles or Systems. This is most likely because"
+            " the database is using the old (v2) style of storing in the database. To"
+            " fix this the roles, principles, systems, instances, and commands"
+            " collections will be dropped."
         )
 
         db = get_db()
@@ -259,8 +254,9 @@ def check_indexes(document_class):
     Raises:
         mongoengine.OperationFailure: Unhandled mongo error
     """
-    from pymongo.errors import OperationFailure
     from mongoengine.connection import get_db
+    from pymongo.errors import OperationFailure
+
     from .models import Request
 
     try:
@@ -308,8 +304,7 @@ def check_indexes(document_class):
             logger.warning("Dropped indexes for %s collection", document_class.__name__)
         except OperationFailure:
             logger.error(
-                "Dropping %s indexes failed, please check the database "
-                "configuration",
+                "Dropping %s indexes failed, please check the database configuration",
                 document_class.__name__,
             )
             raise
@@ -333,7 +328,7 @@ def check_indexes(document_class):
             logger.warning("%s indexes rebuilt successfully", document_class.__name__)
         except OperationFailure:
             logger.error(
-                "%s index rebuild failed, please check the database " "configuration",
+                "%s index rebuild failed, please check the database configuration",
                 document_class.__name__,
             )
             raise
@@ -362,10 +357,10 @@ def _update_request_has_parent_model():
 
 def _create_role(role):
     """Create a role if it doesn't already exist"""
-    from .models import Role
+    from .models import LegacyRole
 
     try:
-        Role.objects.get(name=role.name)
+        LegacyRole.objects.get(name=role.name)
     except DoesNotExist:
         logger.warning("Role %s missing, about to create" % role.name)
         role.save()
