@@ -7,17 +7,19 @@ The request service is responsible for:
 * Request completion notification
 """
 
+import base64
+import gzip
 import json
 import logging
 import re
 import threading
+from builtins import str
+from copy import deepcopy
 from typing import Dict, List, Sequence, Union
 
 import pika.spec
 import six
 import urllib3
-
-from beer_garden.errors import NotUniqueException
 from brewtils.choices import parse
 from brewtils.errors import (
     ConflictError,
@@ -25,13 +27,14 @@ from brewtils.errors import (
     RequestPublishException,
     RequestStatusTransitionError,
 )
-from brewtils.models import Choices, Events, Request, RequestTemplate, System, Operation
-from builtins import str
+from brewtils.models import Choices, Events, Operation, Request, RequestTemplate, System
 from requests import Session
 
 import beer_garden.config as config
 import beer_garden.db.api as db
 import beer_garden.queue.api as queue
+from beer_garden.db.mongo.models import RawFile
+from beer_garden.errors import NotUniqueException
 from beer_garden.events import publish_event
 from beer_garden.metrics import request_completed, request_created, request_started
 
@@ -73,25 +76,20 @@ class RequestValidator(object):
         system = self.get_and_validate_system(request)
         command = self.get_and_validate_command_for_system(request, system)
         request.parameters = self.get_and_validate_parameters(request, command)
-        request.has_parent = self.get_and_validate_parent(request)
+
+        self.validate_parent_status(request)
 
         return request
 
-    def get_and_validate_parent(self, request):
+    def validate_parent_status(self, request):
         """Ensure that a Request's parent request hasn't already completed.
 
         :param request: The request to validate
-        :return: Boolean indicating if this request has a parent
         :raises ConflictError: The parent request has already completed
         """
-        if not request.parent:
-            return False
-
-        if request.parent.status in Request.COMPLETED_STATUSES:
+        if request.parent and request.parent.status in Request.COMPLETED_STATUSES:
             raise ConflictError("Parent request has already completed")
 
-        return True
-
     def get_and_validate_system(self, request):
         """Ensure there is a system in the DB that corresponds to this Request.
 
@@ -439,8 +437,8 @@ class RequestValidator(object):
             request_values = request_value
             if not isinstance(request_values, list):
                 raise ModelValidationError(
-                    "%s was specified as a list, "
-                    "but was not provided as such" % command_parameter.key
+                    "%s was specified as a list, but was not provided as such"
+                    % command_parameter.key
                 )
 
             value_to_return = []
@@ -578,6 +576,23 @@ def get_requests(**kwargs) -> List[Request]:
     return db.query(Request, **kwargs)
 
 
+def _publish_request(request: Request, is_admin: bool, priority: int):
+    """Publish a Request"""
+    queue.put(
+        request,
+        is_admin=is_admin,
+        priority=priority,
+        confirm=True,
+        mandatory=True,
+        delivery_mode=pika.spec.PERSISTENT_DELIVERY_MODE,
+    )
+
+
+def _validate_request(request: Request):
+    """Validates a Request"""
+    return RequestValidator.instance().validate_request(request)
+
+
 def process_request(
     new_request: Union[Request, RequestTemplate],
     wait_event: threading.Event = None,
@@ -604,14 +619,14 @@ def process_request(
     else:
         raise TypeError(
             f"new_request type is {type(new_request)}, expected "
-            f"brewtils.models.Request or brewtils.models.RequestTemplate,"
+            "brewtils.models.Request or brewtils.models.RequestTemplate,"
         )
 
     # Validation is only required for non Admin commands because Admin commands
     # are hard coded to map Plugin functions
     if not is_admin:
         try:
-            request = RequestValidator.instance().validate_request(request)
+            request = _validate_request(request)
         except ModelValidationError:
             invalid_request(request)
             raise
@@ -628,14 +643,7 @@ def process_request(
             request_map[request.id] = wait_event
 
     try:
-        queue.put(
-            request,
-            is_admin=is_admin,
-            priority=priority,
-            confirm=True,
-            mandatory=True,
-            delivery_mode=pika.spec.PERSISTENT_DELIVERY_MODE,
-        )
+        _publish_request(request, is_admin=is_admin, priority=priority)
     except Exception as ex:
         # An error publishing means this request will never complete, so remove it
         if not request.command_type == "EPHEMERAL":
@@ -656,9 +664,63 @@ def process_request(
 
 @publish_event(Events.REQUEST_CREATED)
 def create_request(request: Request) -> Request:
+    """Create a database entry (mongo Document based Request object) from a brewtils
+    Request model object. Some transformations happen on a copy of the supplied Request
+    prior to saving it to the database. The returned Request object is derived from this
+    transformed copy, while the input Request object remains unmodified.
+
+    Args:
+        request: The brewtils Request object from which a database entry will be created
+
+    Returns:
+        Request: A brewtils Request model based on the newly created database entry.
+            The parameters of the returned object may have been modified from the
+            during processing of files in "bytes" type parameters.
+    """
+    # TODO: This deepcopy could be very memory intensive if the request contains large
+    # file parameters. This should be revisited to see if there is a way to persist
+    # remote requests locally without the base64 encoded data while avoiding this copy.
+    request = deepcopy(request)
+    replace_with_raw_file = request.namespace == config.get("garden.name")
+    remove_bytes_parameter_base64(request.parameters, replace_with_raw_file)
+
     return db.create(request)
 
 
+def remove_bytes_parameter_base64(
+    parameters: dict, replace_with_raw_file: bool
+) -> None:
+    """Strips out the "base64" property of any parameters that are of type "bytes".
+    Optionally can create a RawFile object from the "base64" and insert a reference
+    to the RawFile.id in its place.
+
+    This is done because the "base64" property is only used for transport of the
+    request to remote gardens and is never intended to be persisted as an actual
+    parameter.
+
+    Args:
+       parameters: A dict representing the request parameters
+       replace_with_raw_file: If True, a RawFile will be created from the "base64" and
+           an "id" reference to the RawFile will be inserted in place of "base64".
+
+    Returns:
+        None
+    """
+    for param in parameters:
+        request_param = parameters[param]
+        if isinstance(request_param, dict) and request_param.get("type") == "bytes":
+            bytes_base64 = request_param.get("base64")
+
+            if bytes_base64 is not None:
+                if replace_with_raw_file:
+                    raw_file = RawFile(
+                        file=gzip.decompress(base64.b64decode(bytes_base64))
+                    ).save()
+                    request_param["id"] = str(raw_file.id)
+
+                del request_param["base64"]
+
+
 @publish_event(Events.REQUEST_STARTED)
 def start_request(request_id: str = None, request: Request = None) -> Request:
     """Mark a Request as IN PROGRESS
@@ -754,6 +816,12 @@ def invalid_request(request: Request = None):
     return request
 
 
+@publish_event(Events.REQUEST_UPDATED)
+def update_request(request: Request):
+    db.update(request)
+    return request
+
+
 def process_wait(request: Request, timeout: float) -> Request:
     """Helper to process a request and wait for completion using a threading.Event
 
@@ -825,7 +893,7 @@ def handle_event(event):
                     setattr(existing_request, field, getattr(event.payload, field))
 
                 try:
-                    db.update(existing_request)
+                    update_request(existing_request)
                 except RequestStatusTransitionError:
                     pass
             else:
