@@ -48,7 +48,7 @@ from beer_garden.errors import (
 )
 from beer_garden.events import publish
 from beer_garden.garden import get_garden, get_gardens
-from beer_garden.requests import complete_request
+from beer_garden.requests import complete_request, create_request
 
 logger = logging.getLogger(__name__)
 
@@ -110,6 +110,7 @@ route_functions = {
     "INSTANCE_STOP": beer_garden.plugin.stop,
     "INSTANCE_LOGS": beer_garden.plugin.read_logs,
     "JOB_CREATE": beer_garden.scheduler.create_job,
+    "JOB_CREATE_MULTI": beer_garden.scheduler.create_jobs,
     "JOB_UPDATE": beer_garden.scheduler.update_job,
     "JOB_READ": beer_garden.scheduler.get_job,
     "JOB_READ_ALL": beer_garden.scheduler.get_jobs,
@@ -176,13 +177,7 @@ def route(operation: Operation):
         )
 
     # Determine which garden the operation is targeting
-    if not operation.target_garden_name:
-        operation.target_garden_name = _determine_target_garden(operation)
-
-    if not operation.target_garden_name:
-        raise UnknownGardenException(
-            f"Could not determine the target garden for routing {operation!r}"
-        )
+    operation.target_garden_name = _determine_target(operation)
 
     # If it's targeted at THIS garden, execute
     if operation.target_garden_name == config.get("garden.name"):
@@ -286,10 +281,10 @@ def forward(operation: Operation):
 
         if not target_garden.connection_type:
             raise RoutingRequestException(
-                f"Attempted to forward operation to garden "
+                "Attempted to forward operation to garden "
                 f"'{operation.target_garden_name}' but the connection type was None. "
-                f"This probably means that the connection to the child garden has not "
-                f"been configured."
+                "This probably means that the connection to the child garden has not "
+                "been configured."
             )
 
         if target_garden.connection_type.casefold() == "http":
@@ -422,16 +417,20 @@ def handle_event(event):
     elif event.name == Events.SYSTEM_REMOVED.name:
         remove_routing_system(system=event.payload)
 
-    # Handle downstream events
-    if event.garden != config.get("garden.name"):
-        if event.name == Events.GARDEN_SYNC.name and not event.error:
-            with routing_lock:
-                # First remove all current routes to this garden
-                remove_routing_garden(garden_name=event.garden)
+    # Here we want to handle sync events from immediate children only
+    if (
+        not event.error
+        and (event.name == Events.GARDEN_SYNC.name)
+        and (event.garden != config.get("garden.name"))
+        and (event.garden == event.payload.name)
+    ):
+        with routing_lock:
+            # First remove all current routes to this garden
+            remove_routing_garden(garden_name=event.garden)
 
-                # Then add routes to the new systems
-                for system in event.payload.systems:
-                    add_routing_system(system=system, garden_name=event.payload.name)
+            # Then add routes to the new systems
+            for system in event.payload.systems:
+                add_routing_system(system=system, garden_name=event.payload.name)
 
     # This is a little unintuitive. We want to let the garden module deal with handling
     # any downstream garden changes since handling those changes is nontrivial.
@@ -473,13 +472,19 @@ def _pre_route(operation: Operation) -> Operation:
             operation.model.namespace = config.get("garden.name")
 
     elif operation.operation_type == "SYSTEM_READ_ALL":
+        # what looks like a sensible edit is to change the next line to:
+        #   operation.kwargs.get("filter_params", {}).get("namespace", "") == "":
+        # but that will break everything, as it turns out. So, unless
+        # operation.kwargs has a key called filter_params whose value is a dictionary
+        # that has a key called namespace and its value is an empty string, the follow-
+        # ing never runs. Intuition says that's not what was intended here, so
+        # TODO: look into this
         if operation.kwargs.get("filter_params", {}).get("namespace") == "":
             operation.kwargs["filter_params"]["namespace"] = config.get("garden.name")
 
     return operation
 
 
-# TODO - After this is called, if one of the params is a file, ship it down range too.
 def _pre_forward(operation: Operation) -> Operation:
     """Called before forwarding an operation"""
 
@@ -491,15 +496,21 @@ def _pre_forward(operation: Operation) -> Operation:
 
     if operation.operation_type == "REQUEST_CREATE":
         # Save the request so it'll have an ID and we'll have something to update
-        operation.model = db.create(operation.model)
+        local_request = create_request(operation.model)
+
+        if operation.model.namespace == config.get("garden.name"):
+            operation.model = local_request
+        else:
+            # When the target is a remote garden, just capture the id. We don't
+            # want to replace the entire model, as we'd lose the base64 encoded file
+            # parameter data.
+            operation.model.id = local_request.id
 
         # Clear parent before forwarding so the child doesn't freak out about an
         # unknown request
         operation.model.parent = None
         operation.model.has_parent = False
 
-        beer_garden.files.forward_file(operation)
-
         # Pull out and store the wait event, if it exists
         wait_event = operation.kwargs.pop("wait_event", None)
         if wait_event:
@@ -517,9 +528,33 @@ def _pre_execute(operation: Operation) -> Operation:
     return operation
 
 
-def _determine_target_garden(operation: Operation) -> str:
-    """Determine the system the operation is targeting"""
+def _determine_target(operation: Operation) -> str:
+    """Determine the garden the operation is targeting
 
+    Note that while the operation can already have a target garden field this will only
+    be used as a fallback if a better target can't be calculated.
+
+    See https://github.com/beer-garden/beer-garden/issues/1076
+    """
+    target_garden = _target_from_type(operation)
+
+    if not target_garden:
+        if not operation.target_garden_name:
+            raise UnknownGardenException(
+                f"Could not determine the target garden for routing {operation!r}"
+            )
+
+        logger.warning(
+            "Couldn't determine a target garden but the operation had one, using "
+            f"{operation.target_garden_name}"
+        )
+        return operation.target_garden_name
+
+    return target_garden
+
+
+def _target_from_type(operation: Operation) -> str:
+    """Determine the target garden based on the operation type"""
     # Certain operations are ASSUMED to be targeted at the local garden
     if (
         "READ" in operation.operation_type
@@ -642,8 +677,10 @@ def _forward_stomp(operation: Operation, target_garden: Garden) -> None:
         conn.send(body=body, headers=headers)
     except Exception as ex:
         raise ForwardException(
-            message=f"Failed to forward operation to garden "
-            f"'{operation.target_garden_name}' via STOMP.",
+            message=(
+                "Failed to forward operation to garden "
+                f"'{operation.target_garden_name}' via STOMP."
+            ),
             operation=operation,
             event_name=Events.GARDEN_UNREACHABLE.name,
         ) from ex
